@@ -134,9 +134,9 @@ def cli():
     ======================
     dsf-cli upload-batch-files <jars, stages, whl , cluster_init, all>
 
-    Manage
+    Miscellaneous
     Create sonar scanner properties file:
-
+    ====================================
     dsf-cli create-sonar-file current_project_repo_name
 
     Install requirements for trainer
@@ -146,6 +146,10 @@ def cli():
     Install documentation doxygen
     =============================
     dsf-cli install-documentation-requirements
+
+    Deploy project to GAE
+    =====================
+    dsf-cli deploy_service_to_gae
     """
 # @click.option("--type", prompt="type", help="type of component")
 # @click.option("--project_name", prompt="project_name", help="project_name")
@@ -655,7 +659,6 @@ def create_folders(project_name):
     create_main_folders('trainer', 'main')
     create_main_folders('training_output', 'trainer')
     create_main_folders('pl_wrapper', 'trainer')
-    create_main_folders('examples', 'pl_wrapper')
     create_main_folders('server', 'main')
 
 
@@ -702,18 +705,14 @@ def create_project(project_name):
     create_trainer_file(project_name, directories['pl_wrapper'], 'iterable_dataset', False, from_folder='pl_wrapper')
     create_trainer_file(project_name, directories['pl_wrapper'], 'plmodel', False, from_folder='pl_wrapper')
     create_trainer_file(project_name, directories['pl_wrapper'], 'network_module', False, from_folder='pl_wrapper')
-    create_trainer_file(project_name, directories['pl_wrapper'], 'trainer', False, from_folder='pl_wrapper')
-    create_trainer_file(project_name, directories['examples'], 'example1_mnist', False,
-                        from_folder=os.path.join('pl_wrapper', 'examples'))
-    create_trainer_file(project_name, directories['examples'], 'example2_wine_quality', False,
-                        from_folder=os.path.join('pl_wrapper', 'examples'))
     create_trainer_file(project_name, directories['trainer'], 'comparison', False)
     create_trainer_file(project_name, directories['trainer'], 'config', False)
     create_trainer_file(project_name, directories['trainer'], 'data', False)
+    create_trainer_file(project_name, directories['trainer'], 'dataset_preparation', False)
     create_trainer_file(project_name, directories['trainer'], 'model', False)
     create_trainer_file(project_name, directories['trainer'], 'test', False)
     create_trainer_file(project_name, directories['trainer'], 'train', False)
-    create_trainer_file(project_name, directories['trainer'], 'trainer_main', False)
+    create_trainer_file(project_name, directories['trainer'], 'main', False)
     source_path = os.path.join(__location__, 'dsframework/cli/trainer/requirements_trainer.txt')
     shutil.copyfile(source_path, directories['trainer'] + '/requirements_trainer.txt')
 
@@ -1368,37 +1367,35 @@ def copy_trainer_files():
 
     project_name = os.getcwd().split('/')[-1]
     trainer_main_folder = 'trainer/'
-    trainer_datasets_folder = 'trainer/datasets/'
-    trainer_datasets_versions_folder = 'trainer/datasets/my_dataset_name/' + datetime.today().strftime('%Y%m%d_v1') + '/'
-    trainer_examples_folder = 'trainer/examples/'
+    trainer_plwrapper_folder = 'trainer/pl_wrapper/'
 
-    trainer_file_list = ["trainer/custom_dataset",
-                         "trainer/data_module",
-                         "trainer/iterable_dataset",
+    trainer_file_list = ["trainer/pl_wrapper/custom_dataset",
+                         "trainer/pl_wrapper/data_module",
+                         "trainer/pl_wrapper/iterable_dataset",
+                         "trainer/pl_wrapper/network_module",
+                         "trainer/pl_wrapper/plmodel",
+                         "trainer/comparison",
+                         "trainer/config",
+                         "trainer/data",
+                         "trainer/dataset_preparation",
+                         "trainer/main",
                          "trainer/model",
-                         "trainer/network_module",
-                         "trainer/trainer",
-                         "trainer/examples/example1_mnist",
-                         "trainer/examples/example2_wine_quality"]
+                         "trainer/test",
+                         "trainer/train"]
 
     if not os.path.exists(trainer_main_folder):
         os.mkdir(trainer_main_folder)
 
-    if not os.path.exists(trainer_datasets_folder):
-        os.makedirs(trainer_datasets_versions_folder)
-
-    if not os.path.exists(trainer_examples_folder):
-        os.mkdir(trainer_examples_folder)
+    if not os.path.exists(trainer_plwrapper_folder):
+        os.mkdir(trainer_plwrapper_folder)
 
     for filename_path in trainer_file_list:
         file_only = filename_path.split('/')[-1]
         parent_folder = filename_path.split('/')[-2]
 
         dst_folder = ''
-        if parent_folder == 'datasets':
-            dst_folder = trainer_datasets_folder
-        elif parent_folder == 'examples':
-            dst_folder = trainer_examples_folder
+        if parent_folder == 'pl_wrapper':
+            dst_folder = trainer_plwrapper_folder
 
         data = read_template_file(filename_path)
 
@@ -1526,5 +1523,34 @@ def let_user_pick(options):
     return None
 
 
+@cli.command()
+def deploy_service_to_gae():
+    """! Run deployment scripts in order to deploy the current project to GAE.
+   """
+    # Setup paths to script files
+    current_folder = os.path.abspath(os.getcwd())
+    setup_file_path = f"{current_folder}/deploy/setup_deploy_params.sh"
+    framework_folder = os.path.dirname(os.path.abspath(__file__))
+
+    # Check that we have a setup file. If not, copy it.
+    if not os.path.exists(setup_file_path):
+        print(f"file {setup_file_path} doesn't exist. Copying. Please fill relevant parameters and run again")
+        shutil.copyfile(f"{framework_folder}/dsframework/cli/tester/deploy_files/deploy/setup_deploy_params.sh",
+                        setup_file_path)
+        return
+
+    # Prepare commands
+    setup_command = f"source {setup_file_path}"
+    build_command = f"{framework_folder}/dsframework/base/deploy_scripts/build_and_register_image_in_devland.sh"
+    deploy_command = f"{framework_folder}/dsframework/base/deploy_scripts/gae/deploy-gae-devland.sh"
+    full_command = f"{setup_command};{build_command};{deploy_command}"
+
+    # Execute
+    subprocess.call(full_command, shell=True)
+    #subprocess.call(setup_command, shell=True)
+    #subprocess.call(build_command, shell=True)
+    #subprocess.call(deploy_command, shell=True)
+
+
 if __name__ == '__main__':
     cli(prog_name='cli')
